@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,14 +55,14 @@ import java.io.Serializable;
  * {@link Cache} - This class provides an interface for all types of access to the cache.
  * <p>
  * An instance of this class is bound to a specific cache region.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public interface Cache {
 
     /**
      * Removes all of the elements from cache.
-     * 
+     *
      * @throws CacheException If cache cannot be cleared
      */
     public void clear() throws CacheException;
@@ -76,7 +76,7 @@ public interface Cache {
 
     /**
      * Retrieves the object from the cache which is bound to specified key.
-     * 
+     *
      * @param key The key
      * @return The cached object if found or <code>null</code>
      */
@@ -90,7 +90,7 @@ public interface Cache {
      * This method is most useful if you want to determine things such as how long the element has been in the cache.
      * <p>
      * The last access time in the element attributes should be current.
-     * 
+     *
      * @param key The key
      * @return A reference to cache element wrapper if found or <code>null</code>
      */
@@ -101,7 +101,7 @@ public interface Cache {
      * attributes.
      * <p>
      * Each time an element is added to the cache without element attributes, the default element attributes are cloned.
-     * 
+     *
      * @return The default element attributes used by this cache.
      * @throws CacheException If default element attributes cannot be returned
      */
@@ -109,7 +109,7 @@ public interface Cache {
 
     /**
      * Gets an item out of the cache that is in specified group.
-     * 
+     *
      * @param key The key
      * @param group The group name.
      * @return The cached value, <code>null</code> if not found.
@@ -118,7 +118,7 @@ public interface Cache {
 
     /**
      * Invalidates a group: remove all the group members
-     * 
+     *
      * @param group The name of the group to invalidate
      */
     public void invalidateGroup(String group);
@@ -126,7 +126,7 @@ public interface Cache {
     /**
      * Place a new object in the cache, associated with key name. If there is currently an object associated with name in the cache it is
      * replaced. Names are scoped to a cache so they must be unique within the cache they are placed. ObjectExistsException
-     * 
+     *
      * @param key The key
      * @param obj Object to store
      * @exception CacheException If put operation on cache fails
@@ -137,7 +137,7 @@ public interface Cache {
      * Constructs a cache element with these attributes, and puts it into the cache.
      * <p>
      * If the key or the value is null, and InvalidArgumentException is thrown.
-     * 
+     *
      * @param key The key
      * @param val The object to store
      * @param attr The object's element attributes
@@ -148,7 +148,7 @@ public interface Cache {
     /**
      * Allows the user to put an object into a group within a particular cache. This method allows the object's attributes to be
      * individually specified.
-     * 
+     *
      * @param key The key
      * @param groupName The group name.
      * @param value The object to cache
@@ -160,7 +160,7 @@ public interface Cache {
     /**
      * Allows the user to put an object into a group within a particular cache. This method sets the object's attributes to the
      * default for the cache.
-     * 
+     *
      * @param key The key
      * @param groupName The group name.
      * @param value The object to cache
@@ -171,7 +171,7 @@ public interface Cache {
     /**
      * Place a new object in the cache, associated with key. If there is currently an object associated with key in the cache an exception
      * is thrown. Keys are scoped to a cache so they must be unique within the cache they are placed.
-     * 
+     *
      * @param key The key
      * @param value Object to store
      * @exception CacheException If the item is already in the cache.
@@ -180,25 +180,50 @@ public interface Cache {
 
     /**
      * Removes the object from the cache which is bound to specified key.
-     * 
+     *
      * @param key The key
      * @throws CacheException If remove operation on cache fails
      */
     public void remove(Serializable key) throws CacheException;
 
     /**
-     * Removes the object located in specified group and bound to given key.
+     * Removes the object from the cache which is bound to specified key without propagating that operation neither laterally nor remotely.
      * 
      * @param key The key
+     * @throws CacheException If remove operation on cache fails
+     */
+    public void localRemove(Serializable key) throws CacheException;
+
+    /**
+     * Puts the object into the cache which is bound to specified key without propagating that operation neither laterally nor remotely.
+     * 
+     * @param key The key
+     * @param value Object to store
+     * @throws CacheException If put operation on cache fails
+     */
+    public void localPut(Serializable key, Serializable value) throws CacheException;
+
+    /**
+     * Removes the object located in specified group and bound to given key.
+     *
+     * @param key The key
      * @param group The group name.
      */
     public void removeFromGroup(Serializable key, String group);
 
+    /**
+     * Removes the object located in specified group and bound to given key without propagating that operation neither laterally nor remotely.
+     *
+     * @param key The key
+     * @param group The group name.
+     */
+    public void localRemoveFromGroup(Serializable key, String group);
+
     /**
      * This method does not reset the attributes for items already in the cache. It could potentially do this for items in memory, and maybe
      * on disk (which would be slow) but not remote items. Rather than have unpredictable behavior, this method just sets the default
      * attributes. Items subsequently put into the cache will use these defaults if they do not specify specific attributes.
-     * 
+     *
      * @param attr The default attributes.
      * @throws CacheException If default element attributes cannot be applied.
      */
@@ -208,7 +233,7 @@ public interface Cache {
      * This returns the cache statistics with information on this region and its auxiliaries.
      * <p>
      * This data can be formatted as needed.
-     * 
+     *
      * @return The cache statistics with information on this region and its auxiliaries.
      */
     public CacheStatistics getStatistics();
@@ -217,7 +242,7 @@ public interface Cache {
      * Creates a new instance of {@link CacheKey} consisting of specified context ID and object ID.
      * <p>
      * This is a convenience method that delegates to {@link CacheService#newCacheKey(int, int)}.
-     * 
+     *
      * @param contextId The context ID
      * @param objectId The object ID
      * @return The new instance of {@link CacheKey}
@@ -228,7 +253,7 @@ public interface Cache {
      * Creates a new instance of {@link CacheKey} consisting of specified context ID and serializable object.
      * <p>
      * This is a convenience method that delegates to {@link CacheService#newCacheKey(int, Serializable)}.
-     * 
+     *
      * @param contextId The context ID
      * @param objs The serializable objects for the key
      * @return new instance of {@link CacheKey}
