@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,9 +50,14 @@
 package com.openexchange.caching.internal;
 
 import java.io.Serializable;
+import java.lang.reflect.Field;
 import org.apache.jcs.JCS;
+import org.apache.jcs.access.CacheAccess;
 import org.apache.jcs.access.exception.ObjectExistsException;
 import org.apache.jcs.engine.behavior.ICacheElement;
+import org.apache.jcs.engine.control.CompositeCache;
+import org.apache.jcs.engine.control.group.GroupAttrName;
+import org.apache.jcs.engine.control.group.GroupId;
 import com.openexchange.caching.Cache;
 import com.openexchange.caching.CacheElement;
 import com.openexchange.caching.CacheException;
@@ -73,12 +78,24 @@ public final class JCSCache implements Cache {
 
     private final JCS cache;
 
+    private final CompositeCache cacheControl;
+
     /**
      * Initializes a new {@link JCSCache}
      */
     public JCSCache(final JCS cache) {
         super();
         this.cache = cache;
+        // Init CompositeCache reference
+        CompositeCache tmp;
+        try {
+            final Field cacheControlField = CacheAccess.class.getDeclaredField("cacheControl");
+            cacheControlField.setAccessible(true);
+            tmp = (CompositeCache) cacheControlField.get(cache);
+        } catch (final Exception e) {
+            tmp = null;
+        }
+        cacheControl = tmp;
     }
 
     public void clear() throws CacheException {
@@ -171,10 +188,37 @@ public final class JCSCache implements Cache {
         }
     }
 
+    public void localRemove(final Serializable key) throws CacheException {
+        try {
+            cacheControl.localRemove(key);
+        } catch (final Exception e) {
+            throw new CacheException(CacheException.Code.FAILED_REMOVE, e, e.getMessage());
+        }
+    }
+
+    public void localPut(final Serializable key, final Serializable value) throws CacheException {
+        try {
+            final org.apache.jcs.engine.CacheElement ce = new org.apache.jcs.engine.CacheElement(cacheControl.getCacheName(), key, value);
+            ce.setElementAttributes(cacheControl.getElementAttributes());
+            cacheControl.localUpdate(ce);
+        } catch (final Exception e) {
+            throw new CacheException(CacheException.Code.FAILED_PUT, e, e.getMessage());
+        }
+    }
+
     public void removeFromGroup(final Serializable key, final String group) {
         cache.remove(key, group);
     }
 
+    public void localRemoveFromGroup(final Serializable key, final String group) {
+        final GroupAttrName groupAttrName = getGroupAttrName(group, key);
+        this.cacheControl.localRemove(groupAttrName);
+    }
+
+    private GroupAttrName getGroupAttrName(final String group, final Object name) {
+        return new GroupAttrName(new GroupId(this.cacheControl.getCacheName(), group), name);
+    }
+
     public void setDefaultElementAttributes(final ElementAttributes attr) throws CacheException {
         try {
             cache.setDefaultElementAttributes(new JCSElementAttributesDelegator(attr));
@@ -187,7 +231,7 @@ public final class JCSCache implements Cache {
         return new CacheKeyImpl(contextId, objectId);
     }
 
-    public CacheKey newCacheKey(int contextId, Serializable... objs) {
+    public CacheKey newCacheKey(final int contextId, final Serializable... objs) {
         return new CacheKeyImpl(contextId, objs);
     }
 
