@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,18 +64,18 @@ import com.openexchange.caching.CacheInformationMBean;
 /**
  * {@link JCSCacheInformation} - The {@link CacheInformationMBean} implementation of <a href="http://jakarta.apache.org/jcs/">JCS</a>
  * caching system.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class JCSCacheInformation extends StandardMBean implements CacheInformationMBean {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(JCSCacheInformation.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(JCSCacheInformation.class));
 
     private final CompositeCacheManager cacheHub;
 
     /**
      * Initializes a new {@link JCSCacheInformation}.
-     * 
+     *
      * @throws NotCompliantMBeanException
      */
     public JCSCacheInformation() throws NotCompliantMBeanException {
@@ -91,8 +91,8 @@ public class JCSCacheInformation extends StandardMBean implements CacheInformati
         if ("*".equals(name)) {
             final String[] cacheNames = cacheHub.getCacheNames();
             final StringBuilder sb = new StringBuilder(512 * cacheNames.length);
-            for (int i = 0; i < cacheNames.length; i++) {
-                sb.append(cacheHub.getCache(cacheNames[i]).getStats()).append("\r\n\r\n");
+            for (final String cacheName : cacheNames) {
+                sb.append(cacheHub.getCache(cacheName).getStats()).append("\r\n\r\n");
             }
             return sb.toString();
         }
